pub fn drop_root_caps()Expand description
Drop the “root” user capabilities now.
Note: It is not required to explicitly call this function, if you use the ctor feature, which is enabled by default 💡
pub fn drop_root_caps()Drop the “root” user capabilities now.
Note: It is not required to explicitly call this function, if you use the ctor feature, which is enabled by default 💡